==> istio-model-v1beta1-6.8.1-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationMutualTLSFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PeerAuthenticationMutualTLSFluent<A extends PeerAuthenticationMutualTLSFluent<A>> extends BaseFluent<A>{
  public PeerAuthenticationMutualTLSFluent() {
  }
  public PeerAuthenticationMutualTLSFluent(PeerAuthenticationMutualTLS instance) {
    instance = (instance != null ? instance : new PeerAuthenticationMutualTLS());

    if (instance != null) {
      this.withMode(instance.getMode());
      this.withMode(instance.getMode());
    }
  }
  private PeerAuthenticationMutualTLSMode mode;
  public PeerAuthenticationMutualTLSMode getMode() {
    return this.mode;
  }
  public A withMode(PeerAuthenticationMutualTLSMode mode) {
    this.mode=mode; return (A) this;
  }
  public boolean hasMode() {
    return this.mode != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PeerAuthenticationMutualTLSFluent that = (PeerAuthenticationMutualTLSFluent) o;
    if (!java.util.Objects.equals(mode, that.mode)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(mode,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (mode != null) { sb.append("mode:"); sb.append(mode); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationMutualTLSFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PeerAuthenticationMutualTLSFluent<A extends PeerAuthenticationMutualTLSFluent<A>> extends BaseFluent<A>{
  public PeerAuthenticationMutualTLSFluent() {
  }
  
  public PeerAuthenticationMutualTLSFluent(PeerAuthenticationMutualTLS instance) {
    this.copyInstance(instance);
  }
  private PeerAuthenticationMutualTLSMode mode;
  
  protected void copyInstance(PeerAuthenticationMutualTLS instance) {
    instance = (instance != null ? instance : new PeerAuthenticationMutualTLS());
  
    if (instance != null) {
        this.withMode(instance.getMode());
        this.withMode(instance.getMode());
      }
  }
  
  public PeerAuthenticationMutualTLSMode getMode() {
    return this.mode;
  }
  
  public A withMode(PeerAuthenticationMutualTLSMode mode) {
    this.mode=mode; return (A) this;
  }
  
  public boolean hasMode() {
    return this.mode != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PeerAuthenticationMutualTLSFluent that = (PeerAuthenticationMutualTLSFluent) o;
    if (!java.util.Objects.equals(mode, that.mode)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(mode,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (mode != null) { sb.append("mode:"); sb.append(mode); }
    sb.append("}");
    return sb.toString();
  }
  

}
